@@ -58,7 +58,7 @@ def prepare_test(production_name, job_name):
         "application_version": application_version,
         "bk_query": job_data["input"]["bk_query"],
     }
-    if job_data.get("turbo") is not None:
+    if job_data.get("turbo"):
         params["turbo"] = job_data["turbo"]
     data = cern_sso.get_with_cookies(
         urlunparse(ANA_PROD_WEB_URL + ("", urlencode(params), ""))
